#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.features.header.interfaces import IDefaultHeaderRendererSettings
from pyams_content.component.association.interfaces import IAssociationInfo
from pyams_content.features.header.interfaces import IHeaderTarget, IHeaderRenderer, IHeaderSettings, \
    IHeaderRendererSettings
from pyams_skin.layer import IPyAMSLayer

# import packages
from onf_website.features.header import DefaultHeaderRendererSettings
from pyams_content.features.header.skin import BaseHeaderRenderer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config

from onf_website import _


DEFAULT_HEADER_RENDERER_NAME = 'ONF default header'


#
# Default header renderer
#

@adapter_config(name=DEFAULT_HEADER_RENDERER_NAME, context=(IHeaderTarget, IPyAMSLayer), provides=IHeaderRenderer)
@adapter_config(name=DEFAULT_HEADER_RENDERER_NAME, context=(IHeaderSettings, IPyAMSLayer), provides=IHeaderRenderer)
@template_config(template='templates/default-header.pt', layer=IPyAMSLayer)
class ONFDefaultHeaderRenderer(BaseHeaderRenderer):
    """ONF default header renderer"""

    name = DEFAULT_HEADER_RENDERER_NAME
    label = _("ONF default header")
    weight = 1

    settings_key = 'ONF::default'
    settings_interface = IDefaultHeaderRendererSettings

    @staticmethod
    def get_link_info(link):
        return IAssociationInfo(link)


@adapter_config(context=ONFDefaultHeaderRenderer, provides=IHeaderRendererSettings)
def default_header_renderer_settings_factory(context):
    """Default header renderer settings factory"""
    return DefaultHeaderRendererSettings()
